Crate listpack[−][src]
Structs
| Listpack | |
| listpack |
Enums
| Value |
Constants
| AFTER | |
| BEFORE | |
| REPLACE |
Statics
| lp_free | |
| lp_malloc | |
| lp_realloc |
Traits
| Num | |
| Str |
Functions
| allocator⚠ |
Return the existing Rax allocator. |
| lpAppend⚠ | |
| lpAppendInt64⚠ | |
| lpBytes⚠ | |
| lpDelete⚠ | |
| lpFirst⚠ | |
| lpFree⚠ | |
| lpGet⚠ | |
| lpGetInteger⚠ | |
| lpInsert⚠ | |
| lpInsertInt64⚠ | |
| lpLast⚠ | |
| lpLength⚠ | |
| lpNew⚠ | |
| lpNext⚠ | |
| lpPrev⚠ | |
| lpReplaceInt64⚠ | |
| lpSeek⚠ | |
| lp_ll2string⚠ | |
| set_allocator⚠ |
Listpack internally makes calls to "malloc", "realloc" and "free" for all of it's heap memory needs. These calls can be patched with the supplied hooks. Do not call this method after Listpack has been used at all. This must be called before using or calling any Listpack API function. |
Type Definitions
| Element |